"""Processors module for WhoCitedMe."""

from whocitedme.processors.id_matcher import IDMatcher
from whocitedme.processors.top_scholar import TopScholarProcessor

__all__ = ["IDMatcher", "TopScholarProcessor"]
